@@ -1,6 +1,5 @@
+use crate::{load_config::create_deps, CONFIG, DOTDIPLO};
 use anyhow::Result;
-
-use diplo::{info, load_config::create_deps, term::print_inner, CONFIG, DOTDIPLO};
 use serde_json::json;
 use std::fs::write;
 
@@ -18,7 +17,7 @@ pub fn exec() -> Result<()> {
             }
         }
     }
-    info!("Successfully initialized diplo");
+    println!("Successfully initialized diplo");
 
     Ok(())
 }
